@@ -4,7 +4,7 @@ the users at a different degree
 """
 from django.utils.translation import ugettext_lazy as _
 from askbot.conf.settings_wrapper import settings
-from askbot.deps import livesettings
+from livesettings import values as livesettings
 from askbot.conf.super_groups import REP_AND_BADGES
 
 KARMA_AND_BADGE_VISIBILITY = livesettings.ConfigurationGroup(
