@@ -1,12 +1,12 @@
 """
 External service key settings
 """
-from django.utils.translation import string_concat
+from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from askbot.conf.settings_wrapper import settings
 from askbot.conf.super_groups import LOGIN_USERS_COMMUNICATION
-from askbot.deps import livesettings
+from livesettings import values as livesettings
 from askbot.skins import utils as skin_utils
 from askbot.utils.loading import module_exists
 
@@ -231,6 +231,7 @@ providers = (
     'Facebook',
     'Fedora',
     'Flickr',
+    'GitHub',
     'Google Plus',
     'Mozilla Persona',
     'Twitter',
@@ -255,11 +256,11 @@ providers = (
 DISABLED_BY_DEFAULT = ('LaunchPad', 'Mozilla Persona', 'OpenStackID')
 
 NEED_EXTRA_SETUP = ('Google Plus', 'Twitter', 'MediaWiki', 'Facebook',
-                    'LinkedIn', 'identi.ca', 'Yammer', 'Windows Live', 'Microsoft Azure',)
+                    'LinkedIn', 'identi.ca', 'Yammer', 'Windows Live', 'Microsoft Azure', 'GitHub',)
 
 for provider in providers:
     if provider == 'local':
-        provider_string = unicode(_('local password'))
+        provider_string = str(_('local password'))
     else:
         provider_string = provider
 
@@ -300,10 +301,9 @@ for provider in providers:
                 'MEDIAWIKI_ONE_CLICK_REGISTRATION_ENABLED',
                 default=False,
                 description=_('MediaWiki - enable one click registration'),
-                help_text=string_concat(
+                help_text=format_lazy('{} {}',
                     _('Allows skipping the registration page after the wiki '
                       'authentication.'),
-                    ' ',
                     settings.get_related_settings_info(
                         ('EMAIL', 'BLANK_EMAIL_ALLOWED', True, _('Must be enabled')),
                         ('ACCESS_CONTROL', 'REQUIRE_VALID_EMAIL_FOR', True, _('Must be not be required')),
