@@ -8,8 +8,8 @@ from django.core.exceptions import ValidationError
 
 import askbot
 from askbot.conf.settings_wrapper import settings
-from askbot.deps.livesettings import ConfigurationGroup
-from askbot.deps.livesettings import values
+from livesettings.values import ConfigurationGroup
+from livesettings import values
 from askbot.skins import utils as skin_utils
 from askbot import const
 from askbot.conf.super_groups import CONTENT_AND_UI
@@ -61,7 +61,7 @@ settings.register(
 LANG_MODE = getattr(django_settings, 'ASKBOT_LANGUAGE_MODE', 'single-lang')
 HAS_ASKBOT_LOCALE_MIDDLEWARE = (
     'askbot.middleware.locale.LocaleMiddleware' in
-    django_settings.MIDDLEWARE_CLASSES
+    django_settings.MIDDLEWARE
 )
 if LANG_MODE == 'single-lang' and HAS_ASKBOT_LOCALE_MIDDLEWARE:
     settings.register(
