@@ -3,7 +3,7 @@ import re
 import sys
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.uploadedfile import SimpleUploadedFile
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.conf import settings as django_settings
 from django.template import Context
 from django.template.loader import get_template
@@ -20,7 +20,7 @@ try:
 except ImportError:
     raise ImproperlyConfigured("""Askbot: to enable posting by email,
 install modules Lamson and django-lamson:
-pip install Lamson 
+pip install Lamson
 pip install django-lamson
 """)
 
@@ -171,9 +171,9 @@ def process_reply(func):
              received the notification.")
         except Exception as e:
             import sys
-            sys.stderr.write(unicode(e).encode('utf-8'))
+            sys.stderr.write(str(e))
             import traceback
-            sys.stderr.write(unicode(traceback.format_exc()).encode('utf-8'))
+            sys.stderr.write(str(traceback.format_exc()))
 
         if error is not None:
             from askbot.mail.messages import ReplyByEmailError
@@ -199,7 +199,7 @@ def ASK(message, host = None, addr = None):
 
     if DEBUG_EMAIL:
         sys.stderr.write(
-            (u'Received email from %s\n' % from_address).encode('utf-8')
+            ('Received email from %s\n' % from_address).encode('utf-8')
         )
 
 
@@ -242,7 +242,7 @@ def VALIDATE_EMAIL(
     reply_code = reply_address_object.address
 
     if DEBUG_EMAIL:
-        msg = u'Received email validation from %s\n' % from_address
+        msg = 'Received email validation from %s\n' % from_address
         sys.stderr.write(msg.encode('utf-8'))
 
     try:
@@ -283,7 +283,7 @@ def PROCESS(
     the email, including the text body and the file attachments"""
     if DEBUG_EMAIL:
         sys.stderr.write(
-            (u'Received reply from %s\n' % from_address).encode('utf-8')
+            ('Received reply from %s\n' % from_address).encode('utf-8')
         )
     #1) get actual email content
     #   todo: factor this out into the process_reply decorator
@@ -324,5 +324,5 @@ def PROCESS(
         email.send([from_address,])
 
         if DEBUG_EMAIL:
-            msg = u'Sending welcome mail to %s\n' % from_address
+            msg = 'Sending welcome mail to %s\n' % from_address
             sys.stderr.write(msg.encode('utf-8'))
