@@ -1,15 +1,15 @@
-from __future__ import print_function
+
 import datetime
 
 from askbot.models import badges
 from askbot.models import Award
 from askbot.conf import settings as askbot_settings
 from askbot.utils.console import ProgressBar
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from django.utils import timezone
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, *args, **kwargs):
+class Command(BaseCommand):
+    def handle(self, *args, **kwargs):
         help = 'expires RapidResponder badges'
 
         expire_date = timezone.now() - datetime.timedelta(askbot_settings.RAPID_RESPONDER_BADGE_EXPIRES)
