@@ -1,4 +1,4 @@
-from __future__ import print_function
+
 import askbot
 import datetime
 import traceback
@@ -7,7 +7,7 @@ from collections import OrderedDict
 from django.conf import settings as django_settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from django.db import connection
 from django.db.models import Q, F
 from django.utils import timezone
@@ -51,7 +51,7 @@ def extend_question_list(
     """
     if src is None:#is not QuerySet
         return #will not do anything if subscription of this type is not used
-    if limit and len(dst.keys()) >= askbot_settings.MAX_ALERTS_PER_EMAIL:
+    if limit and len(list(dst.keys())) >= askbot_settings.MAX_ALERTS_PER_EMAIL:
         return
     if cutoff_time is None:
         if hasattr(src, 'cutoff_time'):
@@ -90,8 +90,8 @@ def format_action_count(string, number, output):
         output.append(_(string) % {'num':number})
 
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, **options):
+class Command(BaseCommand):
+    def handle(self, **options):
         if askbot_settings.ENABLE_EMAIL_ALERTS:
             activate_language(django_settings.LANGUAGE_CODE)
             for user in User.objects.exclude(askbot_profile__status__in=('b', 't')).iterator():
@@ -105,7 +105,7 @@ class Command(NoArgsCommand):
             connection.close()
 
     def format_debug_msg(self, user, content):
-        msg = u"%s site_id=%d user=%s: %s" % (
+        msg = "%s site_id=%d user=%s: %s" % (
             timezone.now().strftime('%y-%m-%d %h:%m:%s'),
             SITE_ID,
             repr(user.username),
@@ -119,17 +119,17 @@ class Command(NoArgsCommand):
         print(message)
         admin_email = askbot_settings.ADMIN_EMAIL
         try:
-            subject_line = u"Error processing daily/weekly notification for User '%s' for Site '%s'" % (user.username, SITE_ID)
+            subject_line = "Error processing daily/weekly notification for User '%s' for Site '%s'" % (user.username, SITE_ID)
             send_mail(
                 subject_line=subject_line.encode('utf-8'),
                 body_text=message,
                 recipient_list=[admin_email,]
             )
         except:
-            message = u"ERROR: was unable to report this exception to %s: %s" % (admin_email, traceback.format_exc())
+            message = "ERROR: was unable to report this exception to %s: %s" % (admin_email, traceback.format_exc())
             print(self.format_debug_msg(user, message))
         else:
-            message = u"Sent email reporting this exception to %s" % admin_email
+            message = "Sent email reporting this exception to %s" % admin_email
             print(self.format_debug_msg(user, message))
 
     def get_updated_questions_for_user(self, user):
@@ -362,7 +362,7 @@ class Command(NoArgsCommand):
         #for each question, whether it needs to be included or not
         #into the report
 
-        for q, meta_data in q_list.items():
+        for q, meta_data in list(q_list.items()):
             #this loop edits meta_data for each question
             #so that user will receive counts on new edits new answers, etc
             #and marks questions that need to be skipped
@@ -462,26 +462,26 @@ class Command(NoArgsCommand):
         #todo: q_list is a dictionary, not a list
         q_list = self.get_updated_questions_for_user(user)
 
-        if len(q_list.keys()) == 0:
+        if len(list(q_list.keys())) == 0:
             return
 
         num_q = 0
 
-        for question, meta_data in q_list.items():
+        for question, meta_data in list(q_list.items()):
             if meta_data['skip']:
                 del q_list[question]
             else:
                 num_q += 1
         if num_q > 0:
-            threads = Thread.objects.filter(id__in=[qq.thread_id for qq in q_list.keys()])
+            threads = Thread.objects.filter(id__in=[qq.thread_id for qq in list(q_list.keys())])
             tag_summary = Thread.objects.get_tag_summary_from_threads(threads)
 
-            question_count = len(q_list.keys())
+            question_count = len(list(q_list.keys()))
 
             items_added = 0
             items_unreported = 0
             questions_data = list()
-            for q, meta_data in q_list.items():
+            for q, meta_data in list(q_list.items()):
                 act_list = []
                 if meta_data['skip']:
                     continue
