@@ -1,10 +1,10 @@
-from __future__ import print_function
-from django.core.management.base import NoArgsCommand
+
+from django.core.management import BaseCommand
 from django.db import connection
 from askbot.models import EmailFeedSetting, User
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, **options):
+class Command(BaseCommand):
+    def handle(self, **options):
         try:
             try:
                 self.subscribe_everyone()
