@@ -12,6 +12,16 @@ class LocaleMiddleware(object):
     translated to the language the user desires (if the language
     is available, of course).
     """
+    def __init__(self, get_response=None): # i think get_reponse is never None. If it's not another middleware it's the view, I think
+        if get_response is None:
+            get_response = lambda x:x
+        self.get_response = get_response
+
+    def __call__(self, request):
+        self.process_request(request)
+        response = self.get_response(request) # i think this simply chains all middleware
+        response = self.process_response(request, response)
+        return response
 
     def process_request(self, request):
         language = settings.ASKBOT_LANGUAGE
