@@ -1,28 +1,27 @@
-from __future__ import print_function
+
 from askbot.search.state_manager import SearchState
 from django.test import signals
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.core import management
 from django.core.cache.backends.dummy import DummyCache
 from django.core import cache
-import simplejson
+import json
 from django.utils.translation import activate as activate_language
 
-import coffin
-import coffin.template
 from bs4 import BeautifulSoup
 
 import askbot
 from askbot import models
 from askbot.utils.slug import slugify
-from askbot.deployment import package_utils
 from askbot.tests.utils import AskbotTestCase
 from askbot.conf import settings as askbot_settings
 from askbot.tests.utils import skipIf
 from askbot.tests.utils import with_settings
 
+from askbot.skins.template_backends import Template as AskbotTemplate
+
 def patch_jinja2():
     from jinja2 import Template
     ORIG_JINJA2_RENDERER = Template.render
@@ -37,9 +36,7 @@ def patch_jinja2():
         return ORIG_JINJA2_RENDERER(template_object, *args, **kwargs)
     Template.render = instrumented_render
 
-(CMAJOR, CMINOR, CMICRO) = package_utils.get_coffin_version()
-if CMAJOR == 0 and CMINOR == 3 and CMICRO < 4:
-    patch_jinja2()
+patch_jinja2()
 
 
 class PageLoadTestCase(AskbotTestCase):
@@ -59,7 +56,7 @@ class PageLoadTestCase(AskbotTestCase):
     def setUpClass(cls):
         management.call_command('flush', verbosity=0, interactive=False)
         activate_language(settings.LANGUAGE_CODE)
-        management.call_command('askbot_add_test_content', nospam=True, verbosity=0, interactive=False)
+        management.call_command('askbot_add_test_content', verbosity=0, interactive=False)
         super(PageLoadTestCase, cls).setUpClass()
 
     @classmethod
@@ -104,7 +101,7 @@ class PageLoadTestCase(AskbotTestCase):
         else:
             url_info = 'getting url %s' % url
         if data:
-            url_info += '?' + '&'.join(['%s=%s' % (k, v) for k, v in data.iteritems()])
+            url_info += '?' + '&'.join(['%s=%s' % (k, v) for k, v in data.items()])
         print(url_info)
 
         # if redirect expected, but we wont' follow
@@ -124,7 +121,7 @@ class PageLoadTestCase(AskbotTestCase):
 
         if template and status_code != 302:
             if hasattr(r, 'template'):
-                if isinstance(r.template, coffin.template.Template):
+                if isinstance(r.template, AskbotTemplate):
                     self.assertEqual(r.template.name, template)
                     return
 
@@ -150,7 +147,7 @@ class PageLoadTestCase(AskbotTestCase):
         self.assertEqual(response.status_code, 200)
         self.assertTrue(len(response.redirect_chain) == 1)
         redirect_url = response.redirect_chain[0][0]
-        self.assertTrue(unicode(redirect_url).endswith('/questions/'))
+        self.assertTrue(str(redirect_url).endswith('/questions/'))
         if hasattr(response, 'template'):
             templates = response.template
         elif hasattr(response, 'templates'):
@@ -177,7 +174,7 @@ class PageLoadTestCase(AskbotTestCase):
     def test_title_search_groups_disabled(self):
         data = {'query_text': 'Question'}
         response = self.client.get(reverse('api_get_questions'), data)
-        data = simplejson.loads(response.content)
+        data = json.loads(response.content)
         self.assertTrue(len(data) > 1)
 
     @with_settings(GROUPS_ENABLED=True)
@@ -192,13 +189,13 @@ class PageLoadTestCase(AskbotTestCase):
         #ask for data anonymously - should get nothing
         query_data = {'query_text': 'alibaba'}
         response = self.client.get(reverse('api_get_questions'), query_data)
-        response_data = simplejson.loads(response.content)
+        response_data = json.loads(response.content)
         self.assertEqual(len(response_data), 0)
 
         #log in - should get the question
         self.client.login(method='force', user_id=user.id)
         response = self.client.get(reverse('api_get_questions'), query_data)
-        response_data = simplejson.loads(response.content)
+        response_data = json.loads(response.content)
         self.assertEqual(len(response_data), 1)
 
     def test_ask_page_disallowed_anonymous(self):
@@ -453,7 +450,7 @@ class PageLoadTestCase(AskbotTestCase):
         self.proto_test_non_user_urls(status_code=200)
 
     @skipIf('askbot.middleware.forum_mode.ForumModeMiddleware' \
-        not in settings.MIDDLEWARE_CLASSES,
+        not in settings.MIDDLEWARE,
         'no ForumModeMiddleware set')
     @with_settings(ASKBOT_CLOSED_FORUM_MODE=True)
     def test_non_user_urls_in_closed_forum_mode(self):
@@ -525,7 +522,7 @@ class PageLoadTestCase(AskbotTestCase):
         self.proto_test_user_urls(status_code=200)
 
     @skipIf('askbot.middleware.forum_mode.ForumModeMiddleware' \
-        not in settings.MIDDLEWARE_CLASSES,
+        not in settings.MIDDLEWARE,
         'no ForumModeMiddleware set')
     @with_settings(ASKBOT_CLOSED_FORUM_MODE=True)
     def test_user_urls_in_closed_forum_mode(self):
@@ -615,6 +612,9 @@ class QuestionPageRedirectTests(AskbotTestCase):
         self.c.save()
 
     def test_show_bare_question(self):
+        self.q.old_question_id = 101
+        self.q.save()
+
         resp = self.client.get(self.q.get_absolute_url())
         self.assertEqual(200, resp.status_code)
         self.assertEqual(self.q, resp.context['question'])
@@ -637,6 +637,9 @@ class QuestionPageRedirectTests(AskbotTestCase):
         self.assertEqual(self.q, resp.context['question'])
 
     def test_show_answer(self):
+        self.q.old_question_id = 101
+        self.q.save()
+
         resp = self.client.get(self.a.get_absolute_url())
         self.assertEqual(200, resp.status_code)
         self.assertEqual(self.q, resp.context['question'])
@@ -650,7 +653,7 @@ class QuestionPageRedirectTests(AskbotTestCase):
 
         resp = self.client.get(url, data={'answer': self.a.id})
         self.assertEqual(200, resp.status_code)
-        #NOTE: below fails because resp.context in None - why it works in 
+        #NOTE: below fails because resp.context in None - why it works in
         #some cases and not in others???
         #self.assertEqual(self.q, resp.context['question'])
         #self.assertEqual(self.a, resp.context['show_post'])
@@ -689,7 +692,7 @@ class CommandViewTests(AskbotTestCase):
             data = {'object_id': group.id, 'model_name': 'Group'},
         )
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
 
     def test_load_full_object_description_works(self):
         group = models.Group(name='somegroup')
@@ -704,7 +707,7 @@ class CommandViewTests(AskbotTestCase):
             data = {'object_id': group.id,'model_name': 'Group'},
         )
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(response.content, 'some text')
+        self.assertEqual(response.content, b'some text')
 
     def test_save_object_description_works(self):
         group = models.Group(name='somegroup')
@@ -751,18 +754,18 @@ class CommandViewTests(AskbotTestCase):
                                 HTTP_X_REQUESTED_WITH='XMLHttpRequest'
                             )
             self.assertEqual(response.status_code, 200)
-            self.assertEqual(response.content, '')
+            self.assertEqual(response.content, b'')
 
         self.client.login(user_id=user.id, method='force')
 
         from askbot import conf
-        values = dict(conf.get_tag_email_filter_strategy_choices()).keys()
+        values = list(dict(conf.get_tag_email_filter_strategy_choices()).keys())
         for value in values:
             run_test_for_setting(self, 'email', value)
             user = self.reload_object(user)
             self.assertEqual(user.email_tag_filter_strategy, value)
 
-        values = dict(conf.get_tag_display_filter_strategy_choices()).keys()
+        values = list(dict(conf.get_tag_display_filter_strategy_choices()).keys())
         for value in values:
             run_test_for_setting(self, 'display', value)
             user = self.reload_object(user)
