@@ -7,7 +7,7 @@ The "read-only" requirement here is not 100% strict, as for example "question" v
 allow adding new comments via Ajax form post.
 """
 import logging
-import urllib
+import urllib.request, urllib.parse, urllib.error
 import operator
 from django.shortcuts import get_object_or_404
 from django.shortcuts import render
@@ -19,14 +19,14 @@ from django.http import HttpResponseBadRequest
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.template.loader import get_template
 from django.template import Context, RequestContext
-import simplejson
+import json
 from django.utils import timezone
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
 from django.utils import translation
 from django.views.decorators import csrf
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.core import exceptions as django_exceptions
 from django.contrib.humanize.templatetags import humanize
 from django.http import QueryDict
@@ -79,7 +79,7 @@ def questions(request, **kwargs):
         return HttpResponseNotAllowed(['GET'])
 
     search_state = SearchState(
-                    user_logged_in=request.user.is_authenticated(),
+                    user_logged_in=request.user.is_authenticated,
                     **kwargs
                 )
 
@@ -144,7 +144,7 @@ def questions(request, **kwargs):
         rss_query_dict.setlist('tags', search_state.tags)
         context_feed_url += '?' + rss_query_dict.urlencode()
 
-    reset_method_count = len(filter(None, [search_state.query, search_state.tags, meta_data.get('author_name', None)]))
+    reset_method_count = len([_f for _f in [search_state.query, search_state.tags, meta_data.get('author_name', None)] if _f])
 
     if request.is_ajax():
         q_count = paginator.count
@@ -156,28 +156,26 @@ def questions(request, **kwargs):
         if q_count > search_state.page_size:
             paginator_tpl = get_template('main_page/paginator.html')
             paginator_html = paginator_tpl.render(
-                RequestContext(
-                    request, {
+                    {
                         'context': paginator_context,
                         'questions_count': q_count,
                         'page_size' : search_state.page_size,
                         'search_state': search_state,
-                    }
-                )
+                    },
+                    request
             )
         else:
             paginator_html = ''
 
         questions_tpl = get_template('main_page/questions_loop.html')
         questions_html = questions_tpl.render(
-            RequestContext(
-                request, {
+                {
                     'threads': page,
                     'search_state': search_state,
                     'reset_method_count': reset_method_count,
                     'request': request
-                }
-            )
+                },
+                request
         )
 
         ajax_data = {
@@ -208,8 +206,7 @@ def questions(request, **kwargs):
             related_tags_data['font_size'] = extra_tags.get_tag_font_size(related_tags)
 
         ajax_data['related_tags_html'] = related_tags_tpl.render(
-            RequestContext(request, related_tags_data)
-        )
+            related_tags_data, request)
 
         #here we add and then delete some items
         #to allow extra context processor to work
@@ -227,7 +224,7 @@ def questions(request, **kwargs):
 
         ajax_data.update(extra_context)
 
-        return HttpResponse(simplejson.dumps(ajax_data), content_type='application/json')
+        return HttpResponse(json.dumps(ajax_data), content_type='application/json')
 
     else: # non-AJAX branch
 
@@ -275,7 +272,7 @@ def questions(request, **kwargs):
         #and one more thing:) give admin user heads up about
         #setting the domain name if they have not done that yet
         #todo: move this out to a separate middleware
-        if request.user.is_authenticated() and request.user.is_administrator():
+        if request.user.is_authenticated and request.user.is_administrator():
             if domain_is_bad():
                 url = askbot_settings.get_setting_url(('QA_SITE_SETTINGS', 'APP_URL'))
                 msg = _(
@@ -298,7 +295,7 @@ def get_top_answers(request):
         answers = paginator.page(form.cleaned_data['page_number']).object_list
         template = get_template('user_profile/user_answers_list.html')
         answers_html = template.render({'top_answers': answers})
-        json_string = simplejson.dumps({
+        json_string = json.dumps({
                             'html': answers_html,
                             'num_answers': paginator.count}
                         )
@@ -308,7 +305,7 @@ def get_top_answers(request):
 
 def tags(request):#view showing a listing of available tags - plain list
 
-    form = ShowTagsForm(request.REQUEST)
+    form = ShowTagsForm(getattr(request,request.method))
     form.full_clean() #always valid
     page = form.cleaned_data['page']
     sort_method = form.cleaned_data['sort']
@@ -373,9 +370,8 @@ def tags(request):#view showing a listing of available tags - plain list
 
     if request.is_ajax():
         template = get_template('tags/content.html')
-        template_context = RequestContext(request, data)
-        json_data = {'success': True, 'html': template.render(template_context)}
-        json_string = simplejson.dumps(json_data)
+        json_data = {'success': True, 'html': template.render(data,request)}
+        json_string = json.dumps(json_data)
         return HttpResponse(json_string, content_type='application/json')
     else:
         return render(request, 'tags.html', data)
@@ -390,7 +386,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
     #process url parameters
     #todo: fix inheritance of sort method from questions
     #before = timezone.now()
-    form = ShowQuestionForm(request.REQUEST)
+    form = ShowQuestionForm(getattr(request,request.method))
     form.full_clean()#always valid
     show_answer = form.cleaned_data['show_answer']
     show_comment = form.cleaned_data['show_comment']
@@ -445,7 +441,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
     try:
         question_post.assert_is_visible_to(request.user)
     except exceptions.QuestionHidden as error:
-        request.user.message_set.create(message = unicode(error))
+        request.user.message_set.create(message = str(error))
         return HttpResponseRedirect(reverse('index'))
 
     #redirect if slug in the url is wrong
@@ -454,7 +450,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
         lang = translation.get_language()
         question_url = question_post.get_absolute_url(language=lang)
         if request.GET:
-            question_url += u'?' + urllib.urlencode(request.GET)
+            question_url += '?' + urllib.parse.urlencode(request.GET)
         return HttpResponseRedirect(question_url)
 
 
@@ -491,11 +487,11 @@ def question(request, id):#refactor - long subroutine. display question body, an
         try:
             show_comment.assert_is_visible_to(request.user)
         except exceptions.AnswerHidden as error:
-            request.user.message_set.create(message = unicode(error))
+            request.user.message_set.create(message = str(error))
             #use reverse function here because question is not yet loaded
             return HttpResponseRedirect(reverse('question', kwargs = {'id': id}))
         except exceptions.QuestionHidden as error:
-            request.user.message_set.create(message = unicode(error))
+            request.user.message_set.create(message = str(error))
             return HttpResponseRedirect(reverse('index'))
 
     elif show_answer:
@@ -510,7 +506,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
         try:
             show_post.assert_is_visible_to(request.user)
         except django_exceptions.PermissionDenied as error:
-            request.user.message_set.create(message = unicode(error))
+            request.user.message_set.create(message = str(error))
             return HttpResponseRedirect(reverse('question', kwargs = {'id': id}))
 
     thread = question_post.thread
@@ -519,15 +515,15 @@ def question(request, id):#refactor - long subroutine. display question body, an
         request_lang = translation.get_language()
         if request_lang != thread.language_code:
             template = get_template('question/lang_switch_message.html')
-            message = template.render(Context({
+            message = template.render({
                 'post_lang': get_language_name(thread.language_code),
                 'request_lang': get_language_name(request_lang),
                 'home_url': reverse_i18n(request_lang, 'questions')
-            }))
+            })
             request.user.message_set.create(message=message)
             return HttpResponseRedirect(thread.get_absolute_url())
 
-    logging.debug('answer_sort_method=' + unicode(answer_sort_method))
+    logging.debug('answer_sort_method=' + str(answer_sort_method))
 
     #load answers and post id's->athor_id mapping
     #posts are pre-stuffed with the correctly ordered comments
@@ -538,10 +534,10 @@ def question(request, id):#refactor - long subroutine. display question body, an
     user_votes = {}
     user_post_id_list = list()
     #todo: cache this query set, but again takes only 3ms!
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         user_votes = Vote.objects.filter(
                             user=request.user,
-                            voted_post__id__in = post_to_author.keys()
+                            voted_post__id__in = list(post_to_author.keys())
                         ).values_list('voted_post_id', 'vote')
         user_votes = dict(user_votes)
         #we can avoid making this query by iterating through
@@ -585,12 +581,13 @@ def question(request, id):#refactor - long subroutine. display question body, an
     is_cacheable = True
     if show_page != 1:
         is_cacheable = False
-    elif show_comment_position > askbot_settings.MAX_COMMENTS_TO_SHOW:
-        is_cacheable = False
+    # temporary, until invalidation fix. Got broken with Python 3
+    # elif show_comment_position > askbot_settings.MAX_COMMENTS_TO_SHOW:
+    #    is_cacheable = False
 
     #maybe load draft
     initial = {}
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         #todo: refactor into methor on thread
         drafts = models.DraftAnswer.objects.filter(
                                         author=request.user,
@@ -608,13 +605,13 @@ def question(request, id):#refactor - long subroutine. display question body, an
     answer_form = answer_form_class(initial=initial, user=request.user)
 
     user_can_post_comment = (
-        request.user.is_authenticated() \
+        request.user.is_authenticated \
         and request.user.can_post_comment(question_post)
     )
 
     new_answer_allowed = True
     previous_answer = None
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         if askbot_settings.LIMIT_ONE_ANSWER_PER_USER:
             for answer in answers:
                 if answer.author_id == request.user.pk:
@@ -622,7 +619,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
                     previous_answer = answer
                     break
 
-    if request.user.is_authenticated() and askbot_settings.GROUPS_ENABLED:
+    if request.user.is_authenticated and askbot_settings.GROUPS_ENABLED:
         group_read_only = request.user.is_read_only()
     else:
         group_read_only = False
@@ -681,7 +678,7 @@ def revisions(request, id, post_type = None):
     post = get_object_or_404(models.Post, post_type=post_type, id=id)
 
     if post.deleted:
-        if request.user.is_anonymous() \
+        if request.user.is_anonymous \
             or not request.user.is_administrator_or_moderator():
             raise Http404
 
