@@ -4,7 +4,7 @@ from django.shortcuts import render
 from django.http import HttpResponse, Http404
 from django.views.decorators import csrf
 from django.utils import timezone
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.shortcuts import redirect, get_object_or_404
 
 from django.contrib.auth.decorators import login_required
@@ -97,7 +97,7 @@ def ask_widget(request, widget_id):
                 'group_id': group_id,
                 'is_anonymous': ask_anonymously
             }
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 data_dict['author'] = request.user
                 #question = post_question(data_dict, request)
                 return redirect('ask_by_widget_complete')
@@ -109,7 +109,7 @@ def ask_widget(request, widget_id):
     else:
         if 'widget_question' in request.session and \
                 request.GET.get('action', 'post-after-login'):
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 data_dict = request.session['widget_question']
                 data_dict['author'] = request.user
                 question = post_question(request.session['widget_question'], request)
@@ -242,7 +242,7 @@ def render_ask_widget_js(request, widget_id):
         'host': request.get_host(),
         'variable_name': variable_name
     }
-    content =  content_tpl.render(RequestContext(request, context_dict))
+    content =  content_tpl.render(context_dict, request)
     return HttpResponse(content, content_type='text/javascript')
 
 def render_ask_widget_css(request, widget_id):
@@ -255,7 +255,7 @@ def render_ask_widget_css(request, widget_id):
         'editor_type': askbot_settings.EDITOR_TYPE,
         'variable_name': variable_name
     }
-    content =  content_tpl.render(RequestContext(request, context_dict))
+    content =  content_tpl.render(context_dict, request)
     return HttpResponse(content, content_type='text/css')
 
 def question_widget(request, widget_id):
