@@ -20,13 +20,13 @@ from django.http import HttpResponseBadRequest
 from django.http import HttpResponseForbidden
 from django.http import HttpResponseRedirect
 from django.http import Http404
-import simplejson
+import json
 from django.utils import timezone
 from django.utils.html import strip_tags, escape
 from django.utils.translation import get_language
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.core import exceptions
 from django.conf import settings
 from django.views.decorators import csrf
@@ -61,7 +61,7 @@ def upload(request):#ajax upload file to a question or answer
     try:
         #may raise exceptions.PermissionDenied
         result, error, file_url, orig_file_name = None, '', None, None
-        if request.user.is_anonymous():
+        if request.user.is_anonymous:
             msg = _('Sorry, anonymous users cannot upload files')
             raise exceptions.PermissionDenied(msg)
 
@@ -98,9 +98,9 @@ def upload(request):#ajax upload file to a question or answer
             raise exceptions.PermissionDenied(msg)
 
     except exceptions.PermissionDenied as e:
-        error = unicode(e)
+        error = str(e)
     except Exception as e:
-        logging.critical(unicode(e))
+        logging.critical(str(e))
         error = _('Error uploading file. Please contact the site administrator. Thank you.')
 
     if error == '':
@@ -109,7 +109,7 @@ def upload(request):#ajax upload file to a question or answer
         result = ''
         file_url = ''
 
-    #data = simplejson.dumps({
+    #data = json.dumps({
     #    'result': result,
     #    'error': error,
     #    'file_url': file_url
@@ -165,7 +165,7 @@ def import_data(request):
     """
     #allow to use this view to site admins
     #or when the forum in completely empty
-    if request.user.is_anonymous() or (not request.user.is_administrator()):
+    if request.user.is_anonymous or (not request.user.is_administrator()):
         if models.Post.objects.get_questions().exists():
             raise Http404
 
@@ -204,7 +204,7 @@ def ask(request):#view used to ask a new question
     user can start posting a question anonymously but then
     must login/register in order for the question go be shown
     """
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         if request.user.is_read_only():
             referer = request.META.get("HTTP_REFERER", reverse('questions'))
             request.user.message_set.create(message=_('Sorry, but you have only read access'))
@@ -226,16 +226,16 @@ def ask(request):#view used to ask a new question
             group_id = form.cleaned_data.get('group_id', None)
             language = form.cleaned_data.get('language', None)
 
-            content = u'{}\n\n{}\n\n{}'.format(title, tagnames, text)
+            content = '{}\n\n{}\n\n{}'.format(title, tagnames, text)
             if akismet_check_spam(content, request):
                 message = _('Spam was detected on your post, sorry if it was a mistake')
                 raise exceptions.PermissionDenied(message)
 
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 drafts = models.DraftQuestion.objects.filter(author=request.user)
                 drafts.delete()
                 user = form.get_post_user(request.user)
-            elif request.user.is_anonymous() and askbot_settings.ALLOW_ASK_UNREGISTERED:
+            elif request.user.is_anonymous and askbot_settings.ALLOW_ASK_UNREGISTERED:
                 user = models.get_or_create_anonymous_user()
                 ask_anonymously = True
             else:
@@ -262,7 +262,7 @@ def ask(request):#view used to ask a new question
                     )
                     return HttpResponseRedirect(question.get_absolute_url())
                 except exceptions.PermissionDenied as e:
-                    request.user.message_set.create(message = unicode(e))
+                    request.user.message_set.create(message = str(e))
                     return HttpResponseRedirect(reverse('index'))
 
             else:
@@ -291,7 +291,7 @@ def ask(request):#view used to ask a new question
     draft_title = ''
     draft_text = ''
     draft_tagnames = ''
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         drafts = models.DraftQuestion.objects.filter(author=request.user)
         if len(drafts) > 0:
             draft = drafts[0]
@@ -300,15 +300,15 @@ def ask(request):#view used to ask a new question
             draft_tagnames = draft.tagnames
 
     form.initial = {
-        'ask_anonymously': request.REQUEST.get('ask_anonymously', False),
-        'tags': request.REQUEST.get('tags', draft_tagnames),
-        'text': request.REQUEST.get('text', draft_text),
-        'title': request.REQUEST.get('title', draft_title),
-        'post_privately': request.REQUEST.get('post_privately', False),
+        'ask_anonymously': getattr(request,request.method).get('ask_anonymously', False),
+        'tags': getattr(request,request.method).get('tags', draft_tagnames),
+        'text': getattr(request,request.method).get('text', draft_text),
+        'title': getattr(request,request.method).get('title', draft_title),
+        'post_privately': getattr(request,request.method).get('post_privately', False),
         'language': get_language(),
-        'wiki': request.REQUEST.get('wiki', False),
+        'wiki': getattr(request,request.method).get('wiki', False),
     }
-    if 'group_id' in request.REQUEST:
+    if 'group_id' in getattr(request,request.method):
         try:
             group_id = int(request.GET.get('group_id', None))
             form.initial['group_id'] = group_id
@@ -363,7 +363,7 @@ def retag_question(request, id):
                         message = request.user.get_and_delete_messages()[-1]
                         response_data['message'] = message
 
-                    data = simplejson.dumps(response_data)
+                    data = json.dumps(response_data)
                     return HttpResponse(data, content_type="application/json")
                 else:
                     return HttpResponseRedirect(question.get_absolute_url())
@@ -372,7 +372,7 @@ def retag_question(request, id):
                     'message': format_errors(form.errors['tags']),
                     'success': False
                 }
-                data = simplejson.dumps(response_data)
+                data = json.dumps(response_data)
                 return HttpResponse(data, content_type="application/json")
         else:
             form = forms.RetagQuestionForm(question)
@@ -386,13 +386,13 @@ def retag_question(request, id):
     except exceptions.PermissionDenied as e:
         if request.is_ajax():
             response_data = {
-                'message': unicode(e),
+                'message': str(e),
                 'success': False
             }
-            data = simplejson.dumps(response_data)
+            data = json.dumps(response_data)
             return HttpResponse(data, content_type="application/json")
         else:
-            request.user.message_set.create(message = unicode(e))
+            request.user.message_set.create(message = str(e))
             return HttpResponseRedirect(question.get_absolute_url())
 
 @login_required
@@ -514,7 +514,7 @@ def edit_question(request, id):
         return render(request, 'question_edit.html', data)
 
     except exceptions.PermissionDenied as e:
-        request.user.message_set.create(message = unicode(e))
+        request.user.message_set.create(message = str(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
 @login_required
@@ -618,7 +618,7 @@ def edit_answer(request, id):
         return render(request, 'answer_edit.html', data)
 
     except exceptions.PermissionDenied as e:
-        request.user.message_set.create(message = unicode(e))
+        request.user.message_set.create(message = str(e))
         return HttpResponseRedirect(answer.get_absolute_url())
 
 #todo: rename this function to post_new_answer
@@ -653,7 +653,7 @@ def answer(request, id, form_class=forms.AnswerForm):#process a new answer
         form = form_class(request.POST, user=request.user)
 
         if form.is_valid():
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 drafts = models.DraftAnswer.objects.filter(
                                                 author=request.user,
                                                 thread=question.thread
@@ -680,11 +680,11 @@ def answer(request, id, form_class=forms.AnswerForm):#process a new answer
 
                     return HttpResponseRedirect(answer.get_absolute_url())
                 except askbot_exceptions.AnswerAlreadyGiven as e:
-                    request.user.message_set.create(message = unicode(e))
+                    request.user.message_set.create(message = str(e))
                     answer = question.thread.get_answers_by_user(user)[0]
                     return HttpResponseRedirect(answer.get_absolute_url())
                 except exceptions.PermissionDenied as e:
-                    request.user.message_set.create(message = unicode(e))
+                    request.user.message_set.create(message = str(e))
             else:
                 if request.session.session_key is None:
                     return HttpResponseForbidden()
@@ -713,7 +713,7 @@ def __generate_comments_json(obj, user, avatar_size):
     json_comments = []
     for comment in comments:
 
-        if user and user.is_authenticated():
+        if user and user.is_authenticated:
             try:
                 user.assert_can_delete_comment(comment)
                 #/posts/392845/comments/219852/delete
@@ -747,7 +747,7 @@ def __generate_comments_json(obj, user, avatar_size):
         }
         json_comments.append(comment_data)
 
-    data = simplejson.dumps(json_comments)
+    data = json.dumps(json_comments)
     return HttpResponse(data, content_type="application/json")
 
 @csrf.csrf_protect
@@ -757,7 +757,7 @@ def post_comments(request):#generic ajax handler to load comments to an object
     add a new comment to post
     """
     # only support get post comments by ajax now
-    post_type = request.REQUEST.get('post_type', '')
+    post_type = getattr(request,request.method).get('post_type', '')
     if not request.is_ajax() or post_type not in ('question', 'answer'):
         raise Http404  # TODO: Shouldn't be 404! More like 400, 403 or sth more specific
 
@@ -794,7 +794,7 @@ def post_comments(request):#generic ajax handler to load comments to an object
         response = __generate_comments_json(post, user, avatar_size)
     elif request.method == "POST":
         try:
-            if user.is_anonymous():
+            if user.is_anonymous:
                 msg = _('Sorry, you appear to be logged out and '
                         'cannot post comments. Please '
                         '<a href="%(sign_in_url)s">sign in</a>.') % \
@@ -821,14 +821,14 @@ def post_comments(request):#generic ajax handler to load comments to an object
             )
             response = __generate_comments_json(post, user, avatar_size)
         except exceptions.PermissionDenied as e:
-            response = HttpResponseForbidden(unicode(e), content_type="application/json")
+            response = HttpResponseForbidden(str(e), content_type="application/json")
 
     return response
 
 @csrf.csrf_protect
 @decorators.ajax_only
 def edit_comment(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise exceptions.PermissionDenied(_('Sorry, anonymous users cannot edit comments'))
 
     if askbot_settings.READ_ONLY_MODE_ENABLED:
@@ -890,7 +890,7 @@ def delete_comment(request):
     """ajax handler to delete comment
     """
     try:
-        if request.user.is_anonymous():
+        if request.user.is_anonymous:
             msg = _('Sorry, you appear to be logged out and '
                     'cannot delete comments. Please '
                     '<a href="%(sign_in_url)s">sign in</a>.') % \
@@ -925,7 +925,7 @@ def delete_comment(request):
                 )
     except exceptions.PermissionDenied as e:
         return HttpResponseForbidden(
-                    unicode(e),
+                    str(e),
                     content_type='application/json'
                 )
 
@@ -933,7 +933,7 @@ def delete_comment(request):
 @decorators.post_only
 @csrf.csrf_protect
 def comment_to_answer(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         msg = _('Sorry, only logged in users can convert comments to answers. '
                 'Please <a href="%(sign_in_url)s">sign in</a>.') % \
                 {'sign_in_url': url_utils.get_login_url()}
@@ -964,7 +964,7 @@ def repost_answer_as_comment(request, destination=None):
                 'comment_under_previous_answer'
             )
     )
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         msg = _('Sorry, only logged in users can convert answers to comments. '
                 'Please <a href="%(sign_in_url)s">sign in</a>.') % \
                 {'sign_in_url': url_utils.get_login_url()}
